@@ -1,4 +1,4 @@
-# $Id: variogram.gstat.q,v 1.8 2006-12-10 14:17:17 edzer Exp $
+# $Id: variogram.gstat.q,v 1.9 2007-04-06 11:29:58 edzer Exp $
 
 "variogram.gstat" = function (object, ...) {
 	if (!inherits(object, "gstat"))
@@ -11,7 +11,7 @@
 	projected = TRUE
 	for (i in seq(along = object$data)) {
 		d = object$data[[i]]
-		if (i > 1 && !equal.projections(object$data[[1]]$data, d$data))
+		if (i > 1 && !identical(proj4string(object$data[[1]]$data), proj4string(d$data)))
 			stop("data items in gstat object have different coordinate reference systems")
 		raw = gstat.formula(d$formula, d$data)
 		y[[i]] = raw$y
